################################################################################
#
# Copyright 2014
# Author Imran Shakir
#
# All rights reserved. This program and the accompanying materials
# are made available under the terms of the Eclipse Public License v1.0
# which accompanies this distribution, and is available at
# http://www.eclipse.org/legal/epl-v10.html
#
# Contributors:
# Imran Shakir - initial implementation
#
################################################################################
require 'net/http'
require 'uri'

module IIB
  module Node
    class REST
      include IIB::Node

      attr_reader :port

      def initialize(options)
        @hostname = options[:hostname]
        @port     = options[:port]
      end

      def name
        rest_json = get_rest_json
        rest_json["name"]
      end

      def start
        action_not_remotable
      end

      def stop 
        action_not_remotable
      end

      private

      def get_rest_json 
        return @rest_json if !@rest_json.nil?
        @rest_json = top_level_rest_call
      end

      def top_level_rest_call
        uri = URI.parse("http://#{@hostname}:#{@port}/?depth=2")

        request = Net::HTTP::Get.new(uri.to_s)
        request.add_field('Accept', 'application/json')

        response = Net::HTTP.new(uri.host, uri.port).start do |http|
          http.request(request)
        end

        JSON.parse(response.body)
      end

      def action_not_remotable
        fail RuntimeError, "This action is not available on a remote Integration Node"
      end

    end
  end
end